Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(888)

Unified Diff: src/objects.h

Issue 2289683002: [heap] Change LO space limit to 512k - page header (Closed)
Patch Set: Add missing test change from previous CL Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/heap/spaces.h ('k') | test/cctest/test-serialize.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/objects.h
diff --git a/src/objects.h b/src/objects.h
index 320531cfd588aa61ebd344477be4202cd3cd95fb..e109fa68d72db141fbd62564aef50d13072f8e19 100644
--- a/src/objects.h
+++ b/src/objects.h
@@ -10584,12 +10584,13 @@ class JSArray: public JSObject {
static const int kLengthOffset = JSObject::kHeaderSize;
static const int kSize = kLengthOffset + kPointerSize;
// 600 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which
// we do not want to include in objects.h
// Note that Page::kMaxRegularHeapObjectSize has to be in sync with
// kInitialMaxFastElementArray which is checked in a DCHECK in heap.cc.
static const int kInitialMaxFastElementArray =
- (600 * KB - FixedArray::kHeaderSize - kSize - AllocationMemento::kSize) /
+ (512 * KB - 384 - FixedArray::kHeaderSize - kSize -
+ AllocationMemento::kSize) /
kPointerSize;
private:
« no previous file with comments | « src/heap/spaces.h ('k') | test/cctest/test-serialize.cc » ('j') | no next file with comments »
@@ -10584,12 +10584,13 @@ class JSArray: public JSObject {
static const int kLengthOffset = JSObject::kHeaderSize;
static const int kSize = kLengthOffset + kPointerSize;
- // 600 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which
- // we do not want to include in objects.h
+ // (512 * KB - 384) is the Page::kMaxRegularHeapObjectSize defined in spaces.h
+ // which we do not want to include in objects.h
// Note that Page::kMaxRegularHeapObjectSize has to be in sync with
// kInitialMaxFastElementArray which is checked in a DCHECK in heap.cc.

Powered by Google App Engine
This is Rietveld 408576698